import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/legal_document.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:html_unescape/html_unescape.dart';

class LegalDocumentModel extends LegalDocument {
  LegalDocumentModel({
    required String id,
    required String type,
    required int version,
    required String contentUrl,
    required Map<String, String> versionChangesTextMap,
  }) : super(
          id: id,
          type: type,
          version: version,
          contentUrl: contentUrl,
          versionChangesTextMap: versionChangesTextMap,
        );

  factory LegalDocumentModel.fromJson(Map<String, dynamic> json) {
    final userLanguage = ConfigReader.languageCode;
    final defaultLanguage = json[Constants.DOC_DEFAULT_LANGUAGE];

    final content = json[Constants.DOC_CONTENT];
    final langContent = content[userLanguage] ?? content[defaultLanguage];
    final legalDocUrl = langContent[Constants.DOC_LEGAL_DOC_URL];

    final versionChanges = json[Constants.DOC_VERSION_CHANGES] as Map<String, dynamic>;
    final versionChangesTextMap = versionChanges.map<String, String>((key, value) {
      final langValue = value[userLanguage] ?? value[defaultLanguage];
      return MapEntry(key, HtmlUnescape().convert(langValue));
    });

    return LegalDocumentModel(
      id: json[Constants.DOC_ID],
      type: json[Constants.DOC_TYPE],
      version: json[Constants.DOC_VERSION],
      contentUrl: legalDocUrl,
      versionChangesTextMap: versionChangesTextMap,
    );
  }
}
